# Table of Contents

- [user-group-modeling-v3](<./user-group-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: User Group (Meta Model V3 )](<./Modeling-User-Group-Meta-Model-V3-.md>)
  - [Overview](<./Modeling-User-Group-Meta-Model-V3-/Overview.md>)
  - [How to Model User Groups](<./Modeling-User-Group-Meta-Model-V3-/How-to-Model-User-Groups.md>)
